@@ -3,9 +3,12 @@
 #'
 #' @param opts
 #'   List of simulation parameters returned by the function
-#'   \code{antaresRead::setSimulationPath} 
+#'   [antaresRead::setSimulationPath()]
 #'
-#' @return a logical, \code{TRUE} if study is v7 or above, \code{FALSE} otherwise
+#' @return a logical, `TRUE` if study is v7 or above, `FALSE` otherwise.
+#' 
+#' @name check-version
+#' 
 #' @export
 #'
 #' @examples
@@ -18,7 +21,19 @@
 #' }
 #' 
 is_antares_v7 <- function(opts = antaresRead::simOptions()) {
-  new_version <- getOption("antares.version.new", default = 700)
+  assertthat::assert_that(inherits(opts, "simOptions"))
+  new_version <- getOption("antares.version.700", default = 700)
   new_version <- as.numeric(new_version)
   isTRUE(opts$antaresVersion >= new_version)
 }
+
+#' @rdname check-version
+#' 
+#' @export
+is_antares_v820 <- function(opts = antaresRead::simOptions()) {
+  assertthat::assert_that(inherits(opts, "simOptions"))
+  new_version <- getOption("antares.version.820", default = 820)
+  new_version <- as.numeric(new_version)
+  isTRUE(opts$antaresVersion >= new_version)
+}
+
