@@ -1,6 +1,6 @@
 
 utils::globalVariables(
-  c("rn", "variable", "value", "text", "Mode", "Name", "Stats", 
+  c("rn", "variable", "value", "text", "Mode", "Name", "Stats", "menu",
     "area", "day", "getGeographicTrimming", "getIdCols", "link", "time", "timeId",
     "week1", "week2", "year1", "year2"))
 
